<?php
/**
 * @package SS_PiwikTracking
 */

/*
Plugin Name: Piwik tracking, by Sergio Santos
Plugin URI: http://sergiosantos.online/
Description: Add the Piwik tracking code to your website.
Version: 1.0.8
Author: Sergio Santos
Author URI: http://sergiosantos.online/
License: GPLv3 or later
License URI: http://www.gnu.org/licenses/gpl-3.0.html
*/

/*
Copyright (C) 2013-2016  Sergio Santos  (email : mail@sergiosantos.me)

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 3
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*/

if ( !function_exists( 'add_action' ) ) {
	exit;
}

// Set some constants required throughout the application.
define( 'SS_PIWIKTRACKING_VERSION', '1.0.8' );
define( 'SS_PIWIKTRACKING_SLUG', 'piwik-tracking-by-mb' );
define( 'SS_PIWIKTRACKING_PATH', realpath( dirname( __FILE__ ) ) );

/**
 * Plugin's main controller class.
 *
 * Coordinates all of the plugin's functioning.
 *
 * @since 1.0.0
 */
abstract class SS_PiwikTracking {
	/**
	 * Initialise plugin.
	 *
	 * Performs all of the required actions for the plugin to work.
	 *
	 * @since 1.0.0
	 *
	 * @return void
	 */
	public static function init() {
		// Load the translations.
		load_plugin_textdomain( 'SS_PiwikTracking', false, basename( dirname( __FILE__ ) ) . '/assets/i18n' );

		// Load the controllers.
		require_once( 'controllers/backend.class.php' );
		require_once( 'controllers/frontend.class.php' );

		// Set things up.
		SS_PiwikTracking_ControllerBackend::init();
		SS_PiwikTracking_ControllerFrontend::init();

		// ToDo: Find a better way to do this.
		static::update();
	}

	/**
	 * Update plugin.
	 *
	 * Performs all of the required actions upon updating the plugin.
	 *
	 * @since 1.0.8
	 *
	 * @return void
	 */
	public static function update() {
		require_once( 'controllers/backend.class.php' );
		SS_PiwikTracking_ControllerBackend::update();
	}
}

// Update the plugin.
register_activation_hook( __FILE__, array( 'SS_PiwikTracking', 'update' ) );

// Load this plugin.
add_action( 'init', array( 'SS_PiwikTracking', 'init') );

